<?php

namespace App\Models;

use App\Models\Service\AdslTraffic;
use Carbon\Carbon;
use Illuminate\Database\Eloquent\Collection;
use Illuminate\Database\Eloquent\Model;

class AdslSupplier extends Model
{
	protected $table = 'ab_adsl_supplier';

	protected $dates = [
		'stats_lastupdate',
	];

	public $timestamps = FALSE;

	/** SCOPES */

	/**
	 * Only query active categories
	 */
	public function scopeActive($query)
	{
		return $query->where('active',TRUE);
	}

	/** METHODS **/

	/**
	 * Return the traffic records, that were not matched to a service.
	 *
	 * @param Carbon $date
	 * @return Collection
	 */
	public function trafficMismatch(Carbon $date): Collection
	{
		return AdslTraffic::where('date',$date->format('Y-m-d'))
			->where('supplier_id',$this->id)
			->whereNULL('ab_service_adsl_id')
			->get();
	}
}